:mod:`exspy.utils.eds`
----------------------

.. currentmodule:: exspy.utils.eds


.. autosummary::
   cross_section_to_zeta
   electron_range
   get_xray_lines_near_energy
   take_off_angle
   xray_range
   zeta_to_cross_section


.. automodule:: exspy.utils.eds
   :members:
